@@ -2,7 +2,7 @@
 // #![feature(box_syntax)]
 #![forbid(missing_debug_implementations)]
 #![forbid(missing_crate_level_docs)]
-#![doc = include_str!("../readme.md")]
+#![doc = include_str!("../Readme.md")]
 #![doc(html_logo_url = "https://upload.wikimedia.org/wikipedia/commons/d/d5/Tailwind_CSS_Logo.svg")]
 #![doc(html_favicon_url = "https://upload.wikimedia.org/wikipedia/commons/d/d5/Tailwind_CSS_Logo.svg")]
 
