@@ -1,11 +1,10 @@
-use std::{
-    collections::BTreeSet,
-    fmt::{Display, Formatter},
-};
-
 use crate::{
     css_attributes, AnchorPoint, CssAttribute, Result, TailwindArbitrary, TailwindBuilder, TailwindColor, TailwindInstance,
 };
+use std::{
+    collections::BTreeSet,
+    fmt::{Debug, Display, Formatter},
+};
 
 pub use self::{
     attachment::TailwindBackgroundAttachment,
