@@ -1,6 +1,6 @@
 use std::{
     collections::BTreeSet,
-    fmt::{Debug, Display, Formatter},
+    fmt::{Debug, Display, Formatter, Write},
 };
 
 use crate::{
@@ -21,6 +21,7 @@ pub use self::{
     object::*,
     overflow::TailwindOverflow,
     overscroll::TailwindOverscroll,
+    placement::{bottom::TailwindBottom, inset::TailwindInset, left::TailwindLeft, right::TailwindRight, top::TailwindTop},
     position::TailwindPosition,
     visible::TailwindVisibility,
     z_index::TailWindZIndex,
@@ -38,6 +39,7 @@ mod isolate;
 mod object;
 mod overflow;
 mod overscroll;
+mod placement;
 mod position;
 #[cfg(test)]
 mod test;
