@@ -1,7 +1,15 @@
-use super::*;
+mod arbitrary;
 mod display;
 mod methods;
 mod resolver;
+pub use self::arbitrary::TailwindArbitrary;
+use crate::{TailwindBuilder, *};
+use css_color::Srgb;
+use std::{
+    fmt::{Debug, Display, Formatter},
+    str::FromStr,
+};
+use tailwind_ast::{parse_f32, parse_fraction, parse_integer, ASTVariant, AstStyle};
 
 #[cfg(test)]
 pub fn tw_idempotency(input1: &str, builder: &mut TailwindBuilder) {
@@ -30,11 +38,6 @@ pub struct TailwindElements {
     inner: Vec<String>,
 }
 
-#[derive(Debug, Clone)]
-pub struct TailwindArbitrary {
-    inner: String,
-}
-
 /// https://github.com/tw-in-js/twind/blob/main/src/twind/variants.ts
 #[derive(Copy, Clone, Debug)]
 pub enum TailwindVariantKind {
